@@ -1,4 +1,4 @@
-//$Id: labeledoptionmenu.h,v 1.3 2006/07/10 03:15:30 jjongsma Exp $ -*- c++ -*-
+//$Id: labeledoptionmenu.h,v 1.4 2006/07/19 02:55:23 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -19,9 +19,7 @@
 #ifndef GTKMM_EXAMPLE_RANGEWIDGETS_LABELEDOPTIONMENU_H
 #define GTKMM_EXAMPLE_RANGEWIDGETS_LABELEDOPTIONMENU_H
 
-#include <gtkmm/box.h>
-#include <gtkmm/label.h>
-#include <gtkmm/menu.h>
+#include <gtkmm.h>
 
 class LabeledOptionMenu : public Gtk::HBox
 {
