@@ -1,4 +1,4 @@
-//$Id: examplewindow.h,v 1.2 2006/07/10 03:15:31 jjongsma Exp $ -*- c++ -*-
+//$Id: examplewindow.h,v 1.3 2006/07/19 02:55:23 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -19,10 +19,7 @@
 #ifndef GTKMM_EXAMPLEWINDOW_H
 #define GTKMM_EXAMPLEWINDOW_H
 
-#include <gtkmm/window.h>
-#include <gtkmm/box.h>
-#include <gtkmm/uimanager.h>
-#include <gtkmm/recentmanager.h>
+#include <gtkmm.h>
 
 class ExampleWindow : public Gtk::Window
 {
@@ -33,7 +30,9 @@ public:
 protected:
   //Signal handlers:
   virtual void on_menu_file_recent_files_dialog();
+  virtual void on_menu_file_recent_files_menu();
   virtual void on_menu_file_quit();
+  virtual void on_menu_file_new();
 
   //Child widgets:
   Gtk::VBox m_Box;
